# CounterGen

CounterGen is a python module to evaluate language model by generating counterfactual datasets.

To install, run

```console
pip install countergen
```

To see the available commands, run

```console
countergen --help
```
